@@ -9,7 +9,7 @@ void r_vec_poke_range(r_obj* x, r_ssize offset,
                       r_obj* y, r_ssize from, r_ssize to);
 
 
-r_obj* ffi_compiled_by_gcc() {
+r_obj* ffi_compiled_by_gcc(void) {
 #if defined(__GNUC__) && !defined(__clang__)
   return r_true;
   #else
@@ -37,7 +37,7 @@ r_obj* ffi_cnd_type(r_obj* cnd) {
   }
 }
 
-r_obj* ffi_interrupt() {
+r_obj* ffi_interrupt(void) {
   r_interrupt();
   return r_null;
 }
@@ -324,6 +324,47 @@ r_obj* ffi_dyn_list_poke(r_obj* x, r_obj* i, r_obj* value) {
   return r_null;
 }
 
+// [[ register() ]]
+r_obj* ffi_dyn_lgl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_lgl_push_back(r_shelter_deref(x), r_as_bool(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_int_push_back(r_obj* x, r_obj* value) {
+  r_dyn_int_push_back(r_shelter_deref(x), r_as_int(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_dbl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_dbl_push_back(r_shelter_deref(x), r_as_double(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_cpl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_cpl_push_back(r_shelter_deref(x), r_as_complex(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_raw_push_back(r_obj* x, r_obj* value) {
+  r_dyn_raw_push_back(r_shelter_deref(x), r_as_char(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_chr_push_back(r_obj* x, r_obj* value) {
+  r_dyn_chr_push_back(r_shelter_deref(x), value);
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_list_push_back(r_obj* x, r_obj* value) {
+  r_dyn_list_push_back(r_shelter_deref(x), value);
+  return r_null;
+}
+
+// [[ register() ]]
+r_obj* ffi_has_size_one_bool(void) {
+  return r_lgl(sizeof(bool) == 1);
+}
+
 
 // dyn-list-of.c
 
@@ -490,7 +531,7 @@ r_obj* ffi_env_is_browsed(r_obj* env) {
   return r_lgl(RDEBUG(env));
 }
 
-r_obj* ffi_ns_registry_env() {
+r_obj* ffi_ns_registry_env(void) {
   return R_NamespaceRegistry;
 }
 
@@ -693,7 +734,7 @@ r_obj* ffi_is_reference(r_obj* x, r_obj* y) {
   return r_lgl(x == y);
 }
 
-r_obj* ffi_missing_arg() {
+r_obj* ffi_missing_arg(void) {
   return R_MissingArg;
 }
 
@@ -803,9 +844,9 @@ r_obj* ffi_chr_get(r_obj* x, r_obj* i) {
 }
 
 // Returns a copy
-r_obj* ffi_precious_dict() {
+r_obj* ffi_precious_dict(void) {
   // From rlang/sexp.c
-  struct r_dict* rlang__precious_dict();
+  struct r_dict* rlang__precious_dict(void);
 
   struct r_dict* p_dict = rlang__precious_dict();
   return wrap_dict(p_dict);
