@@ -40,22 +40,29 @@ static const R_CallMethodDef r_callables[] = {
   {"ffi_duplicate",                    (DL_FUNC) &ffi_duplicate, 2},
   {"ffi_dyn_chr_get",                  (DL_FUNC) &ffi_dyn_chr_get, 2},
   {"ffi_dyn_chr_poke",                 (DL_FUNC) &ffi_dyn_chr_poke, 3},
+  {"ffi_dyn_chr_push_back",            (DL_FUNC) &ffi_dyn_chr_push_back, 2},
   {"ffi_dyn_cpl_get",                  (DL_FUNC) &ffi_dyn_cpl_get, 2},
   {"ffi_dyn_cpl_poke",                 (DL_FUNC) &ffi_dyn_cpl_poke, 3},
+  {"ffi_dyn_cpl_push_back",            (DL_FUNC) &ffi_dyn_cpl_push_back, 2},
   {"ffi_dyn_dbl_get",                  (DL_FUNC) &ffi_dyn_dbl_get, 2},
   {"ffi_dyn_dbl_poke",                 (DL_FUNC) &ffi_dyn_dbl_poke, 3},
+  {"ffi_dyn_dbl_push_back",            (DL_FUNC) &ffi_dyn_dbl_push_back, 2},
   {"ffi_dyn_info",                     (DL_FUNC) &ffi_dyn_info, 1},
   {"ffi_dyn_int_get",                  (DL_FUNC) &ffi_dyn_int_get, 2},
   {"ffi_dyn_int_poke",                 (DL_FUNC) &ffi_dyn_int_poke, 3},
+  {"ffi_dyn_int_push_back",            (DL_FUNC) &ffi_dyn_int_push_back, 2},
   {"ffi_dyn_lgl_get",                  (DL_FUNC) &ffi_dyn_lgl_get, 2},
   {"ffi_dyn_lgl_poke",                 (DL_FUNC) &ffi_dyn_lgl_poke, 3},
+  {"ffi_dyn_lgl_push_back",            (DL_FUNC) &ffi_dyn_lgl_push_back, 2},
   {"ffi_dyn_list_get",                 (DL_FUNC) &ffi_dyn_list_get, 2},
-  {"ffi_dyn_list_poke",                 (DL_FUNC) &ffi_dyn_list_poke, 3},
+  {"ffi_dyn_list_poke",                (DL_FUNC) &ffi_dyn_list_poke, 3},
+  {"ffi_dyn_list_push_back",           (DL_FUNC) &ffi_dyn_list_push_back, 2},
   {"ffi_dyn_pop_back",                 (DL_FUNC) &ffi_dyn_pop_back, 1},
   {"ffi_dyn_push_back",                (DL_FUNC) &ffi_dyn_push_back, 2},
   {"ffi_dyn_push_back_bool",           (DL_FUNC) &ffi_dyn_push_back_bool, 2},
   {"ffi_dyn_raw_get",                  (DL_FUNC) &ffi_dyn_raw_get, 2},
   {"ffi_dyn_raw_poke",                 (DL_FUNC) &ffi_dyn_raw_poke, 3},
+  {"ffi_dyn_raw_push_back",            (DL_FUNC) &ffi_dyn_raw_push_back, 2},
   {"ffi_dyn_resize",                   (DL_FUNC) &ffi_dyn_resize, 2},
   {"ffi_dyn_unwrap",                   (DL_FUNC) &ffi_dyn_unwrap, 1},
   {"ffi_ellipsis_dots",                (DL_FUNC) &ffi_ellipsis_dots, 1},
